# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class ImportExportApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def import_export_export_xml_file(self, xml_data_format, source_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export the data to an XML file for the current context.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_export_xml_file(xml_data_format, source_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str xml_data_format: The XML file format (Wintax or TeamDB) (required)
        :param str source_id: The Source ID string for which you want to export the data (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_export_xml_file_with_http_info(xml_data_format, source_id, output_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_export_xml_file_with_http_info(xml_data_format, source_id, output_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_export_xml_file_with_http_info(self, xml_data_format, source_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export the data to an XML file for the current context.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_export_xml_file_with_http_info(xml_data_format, source_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str xml_data_format: The XML file format (Wintax or TeamDB) (required)
        :param str source_id: The Source ID string for which you want to export the data (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['xml_data_format', 'source_id', 'output_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_export_xml_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'xml_data_format' is set
        if self.api_client.client_side_validation and ('xml_data_format' not in params or
                                                       params['xml_data_format'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `xml_data_format` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'source_id' is set
        if self.api_client.client_side_validation and ('source_id' not in params or
                                                       params['source_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'output_file_path' is set
        if self.api_client.client_side_validation and ('output_file_path' not in params or
                                                       params['output_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `output_file_path` when calling `import_export_export_xml_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'xml_data_format' in params:
            query_params.append(('xmlDataFormat', params['xml_data_format']))  # noqa: E501
        if 'source_id' in params:
            query_params.append(('sourceId', params['source_id']))  # noqa: E501
        if 'output_file_path' in params:
            query_params.append(('outputFilePath', params['output_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/exportxmlfile', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_export_export_xml_file(self, event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export the data to an XML file for the given context.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_export_xml_file(event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event ID from which perform the export (required)
        :param str car_id: The car ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str session_id: The session ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str run_id: The run ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str lap_id: The lap ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str xml_data_format: The XML file format (Wintax or TeamDB) (required)
        :param str source_id: The Source ID string for which you want to export the data (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_export_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_export_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_export_xml_file_with_http_info(self, event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export the data to an XML file for the given context.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_export_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, xml_data_format, source_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event ID from which perform the export (required)
        :param str car_id: The car ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str session_id: The session ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str run_id: The run ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str lap_id: The lap ID from which perform the export or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str xml_data_format: The XML file format (Wintax or TeamDB) (required)
        :param str source_id: The Source ID string for which you want to export the data (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'car_id', 'session_id', 'run_id', 'lap_id', 'xml_data_format', 'source_id', 'output_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_export_xml_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'car_id' is set
        if self.api_client.client_side_validation and ('car_id' not in params or
                                                       params['car_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `car_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if self.api_client.client_side_validation and ('session_id' not in params or
                                                       params['session_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `session_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'xml_data_format' is set
        if self.api_client.client_side_validation and ('xml_data_format' not in params or
                                                       params['xml_data_format'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `xml_data_format` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'source_id' is set
        if self.api_client.client_side_validation and ('source_id' not in params or
                                                       params['source_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_id` when calling `import_export_export_xml_file`")  # noqa: E501
        # verify the required parameter 'output_file_path' is set
        if self.api_client.client_side_validation and ('output_file_path' not in params or
                                                       params['output_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `output_file_path` when calling `import_export_export_xml_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501
        if 'car_id' in params:
            path_params['carId'] = params['car_id']  # noqa: E501
        if 'session_id' in params:
            path_params['sessionId'] = params['session_id']  # noqa: E501
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501

        query_params = []
        if 'xml_data_format' in params:
            query_params.append(('xmlDataFormat', params['xml_data_format']))  # noqa: E501
        if 'source_id' in params:
            query_params.append(('sourceId', params['source_id']))  # noqa: E501
        if 'output_file_path' in params:
            query_params.append(('outputFilePath', params['output_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/eventId/{eventId}/carId/{carId}/sessionId/{sessionId}/runId/{runId}/lapId/{lapId}/exportxmlfile', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_export_import_excel_file(self, source_path, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an Excel file and a given source Path (sheet name)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_excel_file(source_path, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_path: The source path configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The Excel file path you want to import. For example : C:\\path\\MyFile.xlsx (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_import_excel_file_with_http_info(source_path, input_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_import_excel_file_with_http_info(source_path, input_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_import_excel_file_with_http_info(self, source_path, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an Excel file and a given source Path (sheet name)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_excel_file_with_http_info(source_path, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_path: The source path configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The Excel file path you want to import. For example : C:\\path\\MyFile.xlsx (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source_path', 'input_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_import_excel_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source_path' is set
        if self.api_client.client_side_validation and ('source_path' not in params or
                                                       params['source_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_path` when calling `import_export_import_excel_file`")  # noqa: E501
        # verify the required parameter 'input_file_path' is set
        if self.api_client.client_side_validation and ('input_file_path' not in params or
                                                       params['input_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `input_file_path` when calling `import_export_import_excel_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'source_path' in params:
            query_params.append(('sourcePath', params['source_path']))  # noqa: E501
        if 'input_file_path' in params:
            query_params.append(('inputFilePath', params['input_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/importexcelfile', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_export_import_excel_file(self, source_path, sheetname, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an Excel file and a given source Path (sheet name)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_excel_file(source_path, sheetname, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_path: The source path configured in the teamdb fields that you want to import (required)
        :param str sheetname: The sheet name in the file (required)
        :param str input_file_path: The Excel file path you want to import. For example : C:\\path\\MyFile.xlsx (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_import_excel_file_with_http_info(source_path, sheetname, input_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_import_excel_file_with_http_info(source_path, sheetname, input_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_import_excel_file_with_http_info(self, source_path, sheetname, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an Excel file and a given source Path (sheet name)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_excel_file_with_http_info(source_path, sheetname, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_path: The source path configured in the teamdb fields that you want to import (required)
        :param str sheetname: The sheet name in the file (required)
        :param str input_file_path: The Excel file path you want to import. For example : C:\\path\\MyFile.xlsx (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source_path', 'sheetname', 'input_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_import_excel_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source_path' is set
        if self.api_client.client_side_validation and ('source_path' not in params or
                                                       params['source_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_path` when calling `import_export_import_excel_file`")  # noqa: E501
        # verify the required parameter 'sheetname' is set
        if self.api_client.client_side_validation and ('sheetname' not in params or
                                                       params['sheetname'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `sheetname` when calling `import_export_import_excel_file`")  # noqa: E501
        # verify the required parameter 'input_file_path' is set
        if self.api_client.client_side_validation and ('input_file_path' not in params or
                                                       params['input_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `input_file_path` when calling `import_export_import_excel_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'source_path' in params:
            query_params.append(('sourcePath', params['source_path']))  # noqa: E501
        if 'sheetname' in params:
            query_params.append(('sheetname', params['sheetname']))  # noqa: E501
        if 'input_file_path' in params:
            query_params.append(('inputFilePath', params['input_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/importexcelsheet', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_export_import_xml_file(self, source_id, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an XM Lfile and a given source Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_xml_file(source_id, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_id: The source ID configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The XML file path you want to import. For example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_import_xml_file_with_http_info(source_id, input_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_import_xml_file_with_http_info(source_id, input_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_import_xml_file_with_http_info(self, source_id, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an XM Lfile and a given source Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_xml_file_with_http_info(source_id, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str source_id: The source ID configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The XML file path you want to import. For example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source_id', 'input_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_import_xml_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source_id' is set
        if self.api_client.client_side_validation and ('source_id' not in params or
                                                       params['source_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'input_file_path' is set
        if self.api_client.client_side_validation and ('input_file_path' not in params or
                                                       params['input_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `input_file_path` when calling `import_export_import_xml_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'source_id' in params:
            query_params.append(('sourceId', params['source_id']))  # noqa: E501
        if 'input_file_path' in params:
            query_params.append(('inputFilePath', params['input_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/importxmlfile', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_export_import_xml_file(self, event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an XM Lfile and a given source Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_xml_file(event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event ID to which perform the import (required)
        :param str car_id: The car ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str session_id: The session ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str run_id: The run ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str lap_id: The lap ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str source_id: The source ID configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The XML file path you want to import. For example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_export_import_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.import_export_import_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, **kwargs)  # noqa: E501
            return data

    def import_export_import_xml_file_with_http_info(self, event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, **kwargs):  # noqa: E501
        """[Command] Import the data from an XM Lfile and a given source Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_export_import_xml_file_with_http_info(event_id, car_id, session_id, run_id, lap_id, source_id, input_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event ID to which perform the import (required)
        :param str car_id: The car ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str session_id: The session ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str run_id: The run ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str lap_id: The lap ID to which perform the import or the empty id 00000000-0000-0000-0000-000000000000 (required)
        :param str source_id: The source ID configured in the teamdb fields that you want to import (required)
        :param str input_file_path: The XML file path you want to import. For example : C:\\path\\MyFile.xml (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'car_id', 'session_id', 'run_id', 'lap_id', 'source_id', 'input_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_export_import_xml_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'car_id' is set
        if self.api_client.client_side_validation and ('car_id' not in params or
                                                       params['car_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `car_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if self.api_client.client_side_validation and ('session_id' not in params or
                                                       params['session_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `session_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'lap_id' is set
        if self.api_client.client_side_validation and ('lap_id' not in params or
                                                       params['lap_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `lap_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'source_id' is set
        if self.api_client.client_side_validation and ('source_id' not in params or
                                                       params['source_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `source_id` when calling `import_export_import_xml_file`")  # noqa: E501
        # verify the required parameter 'input_file_path' is set
        if self.api_client.client_side_validation and ('input_file_path' not in params or
                                                       params['input_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `input_file_path` when calling `import_export_import_xml_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501
        if 'car_id' in params:
            path_params['carId'] = params['car_id']  # noqa: E501
        if 'session_id' in params:
            path_params['sessionId'] = params['session_id']  # noqa: E501
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501
        if 'lap_id' in params:
            path_params['lapId'] = params['lap_id']  # noqa: E501

        query_params = []
        if 'source_id' in params:
            query_params.append(('sourceId', params['source_id']))  # noqa: E501
        if 'input_file_path' in params:
            query_params.append(('inputFilePath', params['input_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/eventId/{eventId}/carId/{carId}/sessionId/{sessionId}/runId/{runId}/lapId/{lapId}/importxmlfiletocontext', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class LapReportOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'use_single_lap_mode': 'bool',
        'lap_report_file_format': 'str',
        'lap_report_file_path': 'str'
    }

    attribute_map = {
        'use_single_lap_mode': 'UseSingleLapMode',
        'lap_report_file_format': 'LapReportFileFormat',
        'lap_report_file_path': 'LapReportFilePath'
    }

    def __init__(self, use_single_lap_mode=None, lap_report_file_format=None, lap_report_file_path=None, _configuration=None):  # noqa: E501
        """LapReportOptions - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._use_single_lap_mode = None
        self._lap_report_file_format = None
        self._lap_report_file_path = None
        self.discriminator = None

        self.use_single_lap_mode = use_single_lap_mode
        self.lap_report_file_format = lap_report_file_format
        if lap_report_file_path is not None:
            self.lap_report_file_path = lap_report_file_path

    @property
    def use_single_lap_mode(self):
        """Gets the use_single_lap_mode of this LapReportOptions.  # noqa: E501

        A boolean value that specifies if you want to read only the last lap in the lap report. When the value is false then all the laps will be read  # noqa: E501

        :return: The use_single_lap_mode of this LapReportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_single_lap_mode

    @use_single_lap_mode.setter
    def use_single_lap_mode(self, use_single_lap_mode):
        """Sets the use_single_lap_mode of this LapReportOptions.

        A boolean value that specifies if you want to read only the last lap in the lap report. When the value is false then all the laps will be read  # noqa: E501

        :param use_single_lap_mode: The use_single_lap_mode of this LapReportOptions.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and use_single_lap_mode is None:
            raise ValueError("Invalid value for `use_single_lap_mode`, must not be `None`")  # noqa: E501

        self._use_single_lap_mode = use_single_lap_mode

    @property
    def lap_report_file_format(self):
        """Gets the lap_report_file_format of this LapReportOptions.  # noqa: E501

        The lap report file format : Wintax or Atlas  # noqa: E501

        :return: The lap_report_file_format of this LapReportOptions.  # noqa: E501
        :rtype: str
        """
        return self._lap_report_file_format

    @lap_report_file_format.setter
    def lap_report_file_format(self, lap_report_file_format):
        """Sets the lap_report_file_format of this LapReportOptions.

        The lap report file format : Wintax or Atlas  # noqa: E501

        :param lap_report_file_format: The lap_report_file_format of this LapReportOptions.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and lap_report_file_format is None:
            raise ValueError("Invalid value for `lap_report_file_format`, must not be `None`")  # noqa: E501
        allowed_values = ["Wintax", "Atlas"]  # noqa: E501
        if (self._configuration.client_side_validation and
                lap_report_file_format not in allowed_values):
            raise ValueError(
                "Invalid value for `lap_report_file_format` ({0}), must be one of {1}"  # noqa: E501
                .format(lap_report_file_format, allowed_values)
            )

        self._lap_report_file_format = lap_report_file_format

    @property
    def lap_report_file_path(self):
        """Gets the lap_report_file_path of this LapReportOptions.  # noqa: E501

        The file path to the lap report. You have to provide the file extension and double the \\ characters, for example : C:\\\\\\\\path\\\\\\\\CMyFile.csv  # noqa: E501

        :return: The lap_report_file_path of this LapReportOptions.  # noqa: E501
        :rtype: str
        """
        return self._lap_report_file_path

    @lap_report_file_path.setter
    def lap_report_file_path(self, lap_report_file_path):
        """Sets the lap_report_file_path of this LapReportOptions.

        The file path to the lap report. You have to provide the file extension and double the \\ characters, for example : C:\\\\\\\\path\\\\\\\\CMyFile.csv  # noqa: E501

        :param lap_report_file_path: The lap_report_file_path of this LapReportOptions.  # noqa: E501
        :type: str
        """

        self._lap_report_file_path = lap_report_file_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LapReportOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LapReportOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LapReportOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Run(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'short_name': 'str',
        'number': 'int',
        'order': 'str',
        'session_id': 'str',
        'run_date': 'datetime',
        'run_status': 'str',
        'is_valid': 'bool',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int',
        'tire_set_id': 'str',
        'changed_part': 'str',
        'lap_count': 'int',
        'distance': 'float',
        'distance_real': 'float',
        'used_in_run_plan': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'short_name': 'ShortName',
        'number': 'Number',
        'order': 'Order',
        'session_id': 'SessionId',
        'run_date': 'RunDate',
        'run_status': 'RunStatus',
        'is_valid': 'IsValid',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision',
        'tire_set_id': 'TireSetId',
        'changed_part': 'ChangedPart',
        'lap_count': 'LapCount',
        'distance': 'Distance',
        'distance_real': 'DistanceReal',
        'used_in_run_plan': 'UsedInRunPlan'
    }

    def __init__(self, id=None, short_name=None, number=None, order=None, session_id=None, run_date=None, run_status=None, is_valid=True, last_update_date_utc=None, last_update_user=None, revision=None, tire_set_id=None, changed_part=None, lap_count=None, distance=None, distance_real=None, used_in_run_plan=True, _configuration=None):  # noqa: E501
        """Run - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._short_name = None
        self._number = None
        self._order = None
        self._session_id = None
        self._run_date = None
        self._run_status = None
        self._is_valid = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self._tire_set_id = None
        self._changed_part = None
        self._lap_count = None
        self._distance = None
        self._distance_real = None
        self._used_in_run_plan = None
        self.discriminator = None

        self.id = id
        self.short_name = short_name
        self.number = number
        self.order = order
        self.session_id = session_id
        self.run_date = run_date
        if run_status is not None:
            self.run_status = run_status
        if is_valid is not None:
            self.is_valid = is_valid
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision
        if tire_set_id is not None:
            self.tire_set_id = tire_set_id
        if changed_part is not None:
            self.changed_part = changed_part
        if lap_count is not None:
            self.lap_count = lap_count
        if distance is not None:
            self.distance = distance
        if distance_real is not None:
            self.distance_real = distance_real
        if used_in_run_plan is not None:
            self.used_in_run_plan = used_in_run_plan

    @property
    def id(self):
        """Gets the id of this Run.  # noqa: E501

        The run id.  # noqa: E501

        :return: The id of this Run.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Run.

        The run id.  # noqa: E501

        :param id: The id of this Run.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def short_name(self):
        """Gets the short_name of this Run.  # noqa: E501

        The run short name.  # noqa: E501

        :return: The short_name of this Run.  # noqa: E501
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """Sets the short_name of this Run.

        The run short name.  # noqa: E501

        :param short_name: The short_name of this Run.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and short_name is None:
            raise ValueError("Invalid value for `short_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                short_name is not None and len(short_name) < 1):
            raise ValueError("Invalid value for `short_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._short_name = short_name

    @property
    def number(self):
        """Gets the number of this Run.  # noqa: E501

        The run number.  # noqa: E501

        :return: The number of this Run.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Run.

        The run number.  # noqa: E501

        :param number: The number of this Run.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def order(self):
        """Gets the order of this Run.  # noqa: E501

        The run order.  # noqa: E501

        :return: The order of this Run.  # noqa: E501
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Run.

        The run order.  # noqa: E501

        :param order: The order of this Run.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and order is None:
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                order is not None and len(order) < 1):
            raise ValueError("Invalid value for `order`, length must be greater than or equal to `1`")  # noqa: E501

        self._order = order

    @property
    def session_id(self):
        """Gets the session_id of this Run.  # noqa: E501

        The session unique id to which the run is linked.  # noqa: E501

        :return: The session_id of this Run.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this Run.

        The session unique id to which the run is linked.  # noqa: E501

        :param session_id: The session_id of this Run.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and session_id is None:
            raise ValueError("Invalid value for `session_id`, must not be `None`")  # noqa: E501

        self._session_id = session_id

    @property
    def run_date(self):
        """Gets the run_date of this Run.  # noqa: E501

        The run date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The run_date of this Run.  # noqa: E501
        :rtype: datetime
        """
        return self._run_date

    @run_date.setter
    def run_date(self, run_date):
        """Sets the run_date of this Run.

        The run date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param run_date: The run_date of this Run.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and run_date is None:
            raise ValueError("Invalid value for `run_date`, must not be `None`")  # noqa: E501

        self._run_date = run_date

    @property
    def run_status(self):
        """Gets the run_status of this Run.  # noqa: E501

        The run status.  # noqa: E501

        :return: The run_status of this Run.  # noqa: E501
        :rtype: str
        """
        return self._run_status

    @run_status.setter
    def run_status(self, run_status):
        """Sets the run_status of this Run.

        The run status.  # noqa: E501

        :param run_status: The run_status of this Run.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Service", "Virtual"]  # noqa: E501
        if (self._configuration.client_side_validation and
                run_status not in allowed_values):
            raise ValueError(
                "Invalid value for `run_status` ({0}), must be one of {1}"  # noqa: E501
                .format(run_status, allowed_values)
            )

        self._run_status = run_status

    @property
    def is_valid(self):
        """Gets the is_valid of this Run.  # noqa: E501

        The run \"valid\" status.  # noqa: E501

        :return: The is_valid of this Run.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Run.

        The run \"valid\" status.  # noqa: E501

        :param is_valid: The is_valid of this Run.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Run.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Run.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Run.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Run.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Run.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Run.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Run.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Run.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Run.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Run.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Run.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Run.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def tire_set_id(self):
        """Gets the tire_set_id of this Run.  # noqa: E501

        The tyre set id linked to the run  # noqa: E501

        :return: The tire_set_id of this Run.  # noqa: E501
        :rtype: str
        """
        return self._tire_set_id

    @tire_set_id.setter
    def tire_set_id(self, tire_set_id):
        """Sets the tire_set_id of this Run.

        The tyre set id linked to the run  # noqa: E501

        :param tire_set_id: The tire_set_id of this Run.  # noqa: E501
        :type: str
        """

        self._tire_set_id = tire_set_id

    @property
    def changed_part(self):
        """Gets the changed_part of this Run.  # noqa: E501

        Car Part changed  # noqa: E501

        :return: The changed_part of this Run.  # noqa: E501
        :rtype: str
        """
        return self._changed_part

    @changed_part.setter
    def changed_part(self, changed_part):
        """Sets the changed_part of this Run.

        Car Part changed  # noqa: E501

        :param changed_part: The changed_part of this Run.  # noqa: E501
        :type: str
        """

        self._changed_part = changed_part

    @property
    def lap_count(self):
        """Gets the lap_count of this Run.  # noqa: E501

        Lap count in the run  # noqa: E501

        :return: The lap_count of this Run.  # noqa: E501
        :rtype: int
        """
        return self._lap_count

    @lap_count.setter
    def lap_count(self, lap_count):
        """Sets the lap_count of this Run.

        Lap count in the run  # noqa: E501

        :param lap_count: The lap_count of this Run.  # noqa: E501
        :type: int
        """

        self._lap_count = lap_count

    @property
    def distance(self):
        """Gets the distance of this Run.  # noqa: E501

        Distance performed on the run  # noqa: E501

        :return: The distance of this Run.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Run.

        Distance performed on the run  # noqa: E501

        :param distance: The distance of this Run.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def distance_real(self):
        """Gets the distance_real of this Run.  # noqa: E501

        distance real performed during the run  # noqa: E501

        :return: The distance_real of this Run.  # noqa: E501
        :rtype: float
        """
        return self._distance_real

    @distance_real.setter
    def distance_real(self, distance_real):
        """Sets the distance_real of this Run.

        distance real performed during the run  # noqa: E501

        :param distance_real: The distance_real of this Run.  # noqa: E501
        :type: float
        """

        self._distance_real = distance_real

    @property
    def used_in_run_plan(self):
        """Gets the used_in_run_plan of this Run.  # noqa: E501

        Specify whether the run can be used by a run plan  # noqa: E501

        :return: The used_in_run_plan of this Run.  # noqa: E501
        :rtype: bool
        """
        return self._used_in_run_plan

    @used_in_run_plan.setter
    def used_in_run_plan(self, used_in_run_plan):
        """Sets the used_in_run_plan of this Run.

        Specify whether the run can be used by a run plan  # noqa: E501

        :param used_in_run_plan: The used_in_run_plan of this Run.  # noqa: E501
        :type: bool
        """

        self._used_in_run_plan = used_in_run_plan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Run, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Run):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Run):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class NotesContext(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_id': 'str',
        'car_id': 'str',
        'session_id': 'str',
        'run_id': 'str',
        'lap_id': 'str'
    }

    attribute_map = {
        'event_id': 'EventId',
        'car_id': 'CarId',
        'session_id': 'SessionId',
        'run_id': 'RunId',
        'lap_id': 'LapId'
    }

    def __init__(self, event_id=None, car_id=None, session_id=None, run_id=None, lap_id=None, _configuration=None):  # noqa: E501
        """NotesContext - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._event_id = None
        self._car_id = None
        self._session_id = None
        self._run_id = None
        self._lap_id = None
        self.discriminator = None

        if event_id is not None:
            self.event_id = event_id
        if car_id is not None:
            self.car_id = car_id
        if session_id is not None:
            self.session_id = session_id
        if run_id is not None:
            self.run_id = run_id
        if lap_id is not None:
            self.lap_id = lap_id

    @property
    def event_id(self):
        """Gets the event_id of this NotesContext.  # noqa: E501

        Event unique Id  # noqa: E501

        :return: The event_id of this NotesContext.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this NotesContext.

        Event unique Id  # noqa: E501

        :param event_id: The event_id of this NotesContext.  # noqa: E501
        :type: str
        """

        self._event_id = event_id

    @property
    def car_id(self):
        """Gets the car_id of this NotesContext.  # noqa: E501

        Car unique Id  # noqa: E501

        :return: The car_id of this NotesContext.  # noqa: E501
        :rtype: str
        """
        return self._car_id

    @car_id.setter
    def car_id(self, car_id):
        """Sets the car_id of this NotesContext.

        Car unique Id  # noqa: E501

        :param car_id: The car_id of this NotesContext.  # noqa: E501
        :type: str
        """

        self._car_id = car_id

    @property
    def session_id(self):
        """Gets the session_id of this NotesContext.  # noqa: E501

        Session unique id  # noqa: E501

        :return: The session_id of this NotesContext.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this NotesContext.

        Session unique id  # noqa: E501

        :param session_id: The session_id of this NotesContext.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def run_id(self):
        """Gets the run_id of this NotesContext.  # noqa: E501

        Run unique id  # noqa: E501

        :return: The run_id of this NotesContext.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this NotesContext.

        Run unique id  # noqa: E501

        :param run_id: The run_id of this NotesContext.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def lap_id(self):
        """Gets the lap_id of this NotesContext.  # noqa: E501

        Lap unique id  # noqa: E501

        :return: The lap_id of this NotesContext.  # noqa: E501
        :rtype: str
        """
        return self._lap_id

    @lap_id.setter
    def lap_id(self, lap_id):
        """Sets the lap_id of this NotesContext.

        Lap unique id  # noqa: E501

        :param lap_id: The lap_id of this NotesContext.  # noqa: E501
        :type: str
        """

        self._lap_id = lap_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotesContext, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotesContext):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NotesContext):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class VersionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def version_create_version(self, created_version, **kwargs):  # noqa: E501
        """Create a new version by importing a definition file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_create_version(created_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Version created_version: The version to create. (required)
        :param str default_revision_name: The default name that will be given to the new revisions created during the file import. For example : Rev_000
        :param str assembly_name: The assembly name that will be created during the import.
        :param str copy_from_version: The version id used to copy the group. Set this argument to \"00000000-0000-0000-0000-000000000000\" if you don't want to make a copy.
        :param bool set_default_assembly: True to define the new assembly as the version's default assembly
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_create_version_with_http_info(created_version, **kwargs)  # noqa: E501
        else:
            (data) = self.version_create_version_with_http_info(created_version, **kwargs)  # noqa: E501
            return data

    def version_create_version_with_http_info(self, created_version, **kwargs):  # noqa: E501
        """Create a new version by importing a definition file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_create_version_with_http_info(created_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Version created_version: The version to create. (required)
        :param str default_revision_name: The default name that will be given to the new revisions created during the file import. For example : Rev_000
        :param str assembly_name: The assembly name that will be created during the import.
        :param str copy_from_version: The version id used to copy the group. Set this argument to \"00000000-0000-0000-0000-000000000000\" if you don't want to make a copy.
        :param bool set_default_assembly: True to define the new assembly as the version's default assembly
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['created_version', 'default_revision_name', 'assembly_name', 'copy_from_version', 'set_default_assembly']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version_create_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'created_version' is set
        if self.api_client.client_side_validation and ('created_version' not in params or
                                                       params['created_version'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `created_version` when calling `version_create_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'default_revision_name' in params:
            query_params.append(('defaultRevisionName', params['default_revision_name']))  # noqa: E501
        if 'assembly_name' in params:
            query_params.append(('assemblyName', params['assembly_name']))  # noqa: E501
        if 'copy_from_version' in params:
            query_params.append(('copyFromVersion', params['copy_from_version']))  # noqa: E501
        if 'set_default_assembly' in params:
            query_params.append(('setDefaultAssembly', params['set_default_assembly']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'created_version' in params:
            body_params = params['created_version']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Version',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def version_get_version(self, version_id, **kwargs):  # noqa: E501
        """Get a version via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_get_version(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want to get the version (required)
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_get_version_with_http_info(version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.version_get_version_with_http_info(version_id, **kwargs)  # noqa: E501
            return data

    def version_get_version_with_http_info(self, version_id, **kwargs):  # noqa: E501
        """Get a version via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_get_version_with_http_info(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want to get the version (required)
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version_get_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `version_get_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Version',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def version_get_versions(self, target_id, **kwargs):  # noqa: E501
        """Get the list of all versions for a given target  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_get_versions(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: The unique target id to wich you want to get the versions. (required)
        :return: list[Version]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_get_versions_with_http_info(target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.version_get_versions_with_http_info(target_id, **kwargs)  # noqa: E501
            return data

    def version_get_versions_with_http_info(self, target_id, **kwargs):  # noqa: E501
        """Get the list of all versions for a given target  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_get_versions_with_http_info(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: The unique target id to wich you want to get the versions. (required)
        :return: list[Version]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version_get_versions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `version_get_versions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'target_id' in params:
            path_params['targetId'] = params['target_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/target/{targetId}/versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Version]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def version_update_version(self, version_id, updated_version, **kwargs):  # noqa: E501
        """Update an existing version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_update_version(version_id, updated_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id corresponding to the version you want to update. (required)
        :param Version updated_version: The version to update. (required)
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_update_version_with_http_info(version_id, updated_version, **kwargs)  # noqa: E501
        else:
            (data) = self.version_update_version_with_http_info(version_id, updated_version, **kwargs)  # noqa: E501
            return data

    def version_update_version_with_http_info(self, version_id, updated_version, **kwargs):  # noqa: E501
        """Update an existing version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_update_version_with_http_info(version_id, updated_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id corresponding to the version you want to update. (required)
        :param Version updated_version: The version to update. (required)
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'updated_version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version_update_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `version_update_version`")  # noqa: E501
        # verify the required parameter 'updated_version' is set
        if self.api_client.client_side_validation and ('updated_version' not in params or
                                                       params['updated_version'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_version` when calling `version_update_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_version' in params:
            body_params = params['updated_version']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Version',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from teamdbapi.api.assembly_api import AssemblyApi
from teamdbapi.api.car_api import CarApi
from teamdbapi.api.config_api import ConfigApi
from teamdbapi.api.edit_api import EditApi
from teamdbapi.api.event_api import EventApi
from teamdbapi.api.fixed_field_api import FixedFieldApi
from teamdbapi.api.group_api import GroupApi
from teamdbapi.api.import_export_api import ImportExportApi
from teamdbapi.api.lap_api import LapApi
from teamdbapi.api.lap_report_api import LapReportApi
from teamdbapi.api.model_field_api import ModelFieldApi
from teamdbapi.api.notes_authorization_api import NotesAuthorizationApi
from teamdbapi.api.parameter_api import ParameterApi
from teamdbapi.api.report_api import ReportApi
from teamdbapi.api.revision_api import RevisionApi
from teamdbapi.api.revision_editor_selector_api import RevisionEditorSelectorApi
from teamdbapi.api.run_api import RunApi
from teamdbapi.api.script_api import ScriptApi
from teamdbapi.api.session_api import SessionApi
from teamdbapi.api.target_api import TargetApi
from teamdbapi.api.team_db_list_api import TeamDBListApi
from teamdbapi.api.team_db_view_api import TeamDBViewApi
from teamdbapi.api.tire_api import TireApi
from teamdbapi.api.tire_set_api import TireSetApi
from teamdbapi.api.track_api import TrackApi
from teamdbapi.api.track_layout_api import TrackLayoutApi
from teamdbapi.api.user_api import UserApi
from teamdbapi.api.value_field_api import ValueFieldApi
from teamdbapi.api.version_api import VersionApi



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class GroupApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def group_create_group(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        Set Group.Id to Guid.Empty (00000000-0000-0000-0000-000000000000) in order to create a new group. The id will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_create_group(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Group group: The group to create. (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_create_group_with_http_info(group, **kwargs)  # noqa: E501
        else:
            (data) = self.group_create_group_with_http_info(group, **kwargs)  # noqa: E501
            return data

    def group_create_group_with_http_info(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        Set Group.Id to Guid.Empty (00000000-0000-0000-0000-000000000000) in order to create a new group. The id will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_create_group_with_http_info(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Group group: The group to create. (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_create_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group' is set
        if self.api_client.client_side_validation and ('group' not in params or
                                                       params['group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group` when calling `group_create_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in params:
            body_params = params['group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def group_delete_group(self, group_id, **kwargs):  # noqa: E501
        """Delete a group corresponding to an Id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_delete_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id corresponding to the group to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_delete_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.group_delete_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def group_delete_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Delete a group corresponding to an Id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_delete_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id corresponding to the group to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_delete_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `group_delete_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/group/{groupId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def group_get_group(self, group_id, **kwargs):  # noqa: E501
        """Get a group via its Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id to which you want to get the group (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_get_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.group_get_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def group_get_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get a group via its Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id to which you want to get the group (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_get_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `group_get_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/group/{groupId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def group_get_group_full_path(self, group_id, **kwargs):  # noqa: E501
        """Get the full path of a group via its Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_group_full_path(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id to which you want the full path. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_get_group_full_path_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.group_get_group_full_path_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def group_get_group_full_path_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get the full path of a group via its Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_group_full_path_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The unique group id to which you want the full path. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_get_group_full_path" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `group_get_group_full_path`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/group/{groupId}/fullpath', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def group_get_groups(self, version_id, **kwargs):  # noqa: E501
        """Get all groups for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_groups(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want the groups. (required)
        :return: list[Group]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_get_groups_with_http_info(version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.group_get_groups_with_http_info(version_id, **kwargs)  # noqa: E501
            return data

    def group_get_groups_with_http_info(self, version_id, **kwargs):  # noqa: E501
        """Get all groups for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_get_groups_with_http_info(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The unique version id to which you want the groups. (required)
        :return: list[Group]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_get_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `group_get_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Group]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def group_update_group(self, group_id, group, **kwargs):  # noqa: E501
        """Update a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_update_group(group_id, group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group id corresponding to the group you want to update. (required)
        :param Group group: The group to update. (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.group_update_group_with_http_info(group_id, group, **kwargs)  # noqa: E501
        else:
            (data) = self.group_update_group_with_http_info(group_id, group, **kwargs)  # noqa: E501
            return data

    def group_update_group_with_http_info(self, group_id, group, **kwargs):  # noqa: E501
        """Update a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.group_update_group_with_http_info(group_id, group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group id corresponding to the group you want to update. (required)
        :param Group group: The group to update. (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method group_update_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `group_update_group`")  # noqa: E501
        # verify the required parameter 'group' is set
        if self.api_client.client_side_validation and ('group' not in params or
                                                       params['group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group` when calling `group_update_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in params:
            body_params = params['group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/group/{groupId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ValueField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'model_field_id': 'str',
        'value': 'object',
        'is_valid': 'bool',
        'parent_item_id': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'model_field_id': 'ModelFieldId',
        'value': 'Value',
        'is_valid': 'IsValid',
        'parent_item_id': 'ParentItemId',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser'
    }

    def __init__(self, id=None, model_field_id=None, value=None, is_valid=True, parent_item_id=None, last_update_date_utc=None, last_update_user=None, _configuration=None):  # noqa: E501
        """ValueField - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._model_field_id = None
        self._value = None
        self._is_valid = None
        self._parent_item_id = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self.discriminator = None

        self.id = id
        self.model_field_id = model_field_id
        if value is not None:
            self.value = value
        if is_valid is not None:
            self.is_valid = is_valid
        self.parent_item_id = parent_item_id
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user

    @property
    def id(self):
        """Gets the id of this ValueField.  # noqa: E501

        The unique value field Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Value Field.  # noqa: E501

        :return: The id of this ValueField.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ValueField.

        The unique value field Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Value Field.  # noqa: E501

        :param id: The id of this ValueField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def model_field_id(self):
        """Gets the model_field_id of this ValueField.  # noqa: E501

        The model field id to which the value is linked  # noqa: E501

        :return: The model_field_id of this ValueField.  # noqa: E501
        :rtype: str
        """
        return self._model_field_id

    @model_field_id.setter
    def model_field_id(self, model_field_id):
        """Sets the model_field_id of this ValueField.

        The model field id to which the value is linked  # noqa: E501

        :param model_field_id: The model_field_id of this ValueField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and model_field_id is None:
            raise ValueError("Invalid value for `model_field_id`, must not be `None`")  # noqa: E501

        self._model_field_id = model_field_id

    @property
    def value(self):
        """Gets the value of this ValueField.  # noqa: E501

        The value object.  # noqa: E501

        :return: The value of this ValueField.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ValueField.

        The value object.  # noqa: E501

        :param value: The value of this ValueField.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def is_valid(self):
        """Gets the is_valid of this ValueField.  # noqa: E501

        Set to True when the value is valid.  # noqa: E501

        :return: The is_valid of this ValueField.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this ValueField.

        Set to True when the value is valid.  # noqa: E501

        :param is_valid: The is_valid of this ValueField.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def parent_item_id(self):
        """Gets the parent_item_id of this ValueField.  # noqa: E501

        The id of the parent entity (event, car, session, run, lap) which owns the value.  # noqa: E501

        :return: The parent_item_id of this ValueField.  # noqa: E501
        :rtype: str
        """
        return self._parent_item_id

    @parent_item_id.setter
    def parent_item_id(self, parent_item_id):
        """Sets the parent_item_id of this ValueField.

        The id of the parent entity (event, car, session, run, lap) which owns the value.  # noqa: E501

        :param parent_item_id: The parent_item_id of this ValueField.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and parent_item_id is None:
            raise ValueError("Invalid value for `parent_item_id`, must not be `None`")  # noqa: E501

        self._parent_item_id = parent_item_id

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this ValueField.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this ValueField.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this ValueField.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this ValueField.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this ValueField.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this ValueField.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this ValueField.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this ValueField.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValueField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValueField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ValueField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TrackLayoutApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def track_layout_create_track_layout(self, new_track_layout, **kwargs):  # noqa: E501
        """Create a new trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_create_track_layout(new_track_layout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TrackLayout new_track_layout: The trackLayout to create. (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_layout_create_track_layout_with_http_info(new_track_layout, **kwargs)  # noqa: E501
        else:
            (data) = self.track_layout_create_track_layout_with_http_info(new_track_layout, **kwargs)  # noqa: E501
            return data

    def track_layout_create_track_layout_with_http_info(self, new_track_layout, **kwargs):  # noqa: E501
        """Create a new trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_create_track_layout_with_http_info(new_track_layout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TrackLayout new_track_layout: The trackLayout to create. (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_track_layout']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_layout_create_track_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_track_layout' is set
        if self.api_client.client_side_validation and ('new_track_layout' not in params or
                                                       params['new_track_layout'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_track_layout` when calling `track_layout_create_track_layout`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_track_layout' in params:
            body_params = params['new_track_layout']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tracklayout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TrackLayout',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_layout_delete_track_layout(self, track_layout_id, **kwargs):  # noqa: E501
        """Delete an existing trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_delete_track_layout(track_layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to delete the trackLayout (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_layout_delete_track_layout_with_http_info(track_layout_id, **kwargs)  # noqa: E501
        else:
            (data) = self.track_layout_delete_track_layout_with_http_info(track_layout_id, **kwargs)  # noqa: E501
            return data

    def track_layout_delete_track_layout_with_http_info(self, track_layout_id, **kwargs):  # noqa: E501
        """Delete an existing trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_delete_track_layout_with_http_info(track_layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to delete the trackLayout (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_layout_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_layout_delete_track_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_layout_id' is set
        if self.api_client.client_side_validation and ('track_layout_id' not in params or
                                                       params['track_layout_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_layout_id` when calling `track_layout_delete_track_layout`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_layout_id' in params:
            path_params['trackLayoutId'] = params['track_layout_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tracklayout/{trackLayoutId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_layout_get_track_layout(self, track_layout_id, **kwargs):  # noqa: E501
        """Get an trackLayout via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_get_track_layout(track_layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to get the trackLayout (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_layout_get_track_layout_with_http_info(track_layout_id, **kwargs)  # noqa: E501
        else:
            (data) = self.track_layout_get_track_layout_with_http_info(track_layout_id, **kwargs)  # noqa: E501
            return data

    def track_layout_get_track_layout_with_http_info(self, track_layout_id, **kwargs):  # noqa: E501
        """Get an trackLayout via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_get_track_layout_with_http_info(track_layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to get the trackLayout (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_layout_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_layout_get_track_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_layout_id' is set
        if self.api_client.client_side_validation and ('track_layout_id' not in params or
                                                       params['track_layout_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_layout_id` when calling `track_layout_get_track_layout`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_layout_id' in params:
            path_params['trackLayoutId'] = params['track_layout_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tracklayout/{trackLayoutId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TrackLayout',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_layout_get_track_layouts(self, track_id, **kwargs):  # noqa: E501
        """Get the list of all track layouts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_get_track_layouts(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to get the trackLayouts (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_layout_get_track_layouts_with_http_info(track_id, **kwargs)  # noqa: E501
        else:
            (data) = self.track_layout_get_track_layouts_with_http_info(track_id, **kwargs)  # noqa: E501
            return data

    def track_layout_get_track_layouts_with_http_info(self, track_id, **kwargs):  # noqa: E501
        """Get the list of all track layouts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_get_track_layouts_with_http_info(track_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_id: The unique track id for which you want to get the trackLayouts (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_layout_get_track_layouts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_id' is set
        if self.api_client.client_side_validation and ('track_id' not in params or
                                                       params['track_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_id` when calling `track_layout_get_track_layouts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_id' in params:
            path_params['trackId'] = params['track_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/track/{trackId}/layouts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def track_layout_update_track_layout(self, track_layout_id, updated_track_layout, **kwargs):  # noqa: E501
        """Update an existing trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_update_track_layout(track_layout_id, updated_track_layout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to update the trackLayout (required)
        :param TrackLayout updated_track_layout: The trackLayout to update. (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.track_layout_update_track_layout_with_http_info(track_layout_id, updated_track_layout, **kwargs)  # noqa: E501
        else:
            (data) = self.track_layout_update_track_layout_with_http_info(track_layout_id, updated_track_layout, **kwargs)  # noqa: E501
            return data

    def track_layout_update_track_layout_with_http_info(self, track_layout_id, updated_track_layout, **kwargs):  # noqa: E501
        """Update an existing trackLayout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.track_layout_update_track_layout_with_http_info(track_layout_id, updated_track_layout, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str track_layout_id: The unique trackLayout id for which you want to update the trackLayout (required)
        :param TrackLayout updated_track_layout: The trackLayout to update. (required)
        :return: TrackLayout
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['track_layout_id', 'updated_track_layout']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method track_layout_update_track_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'track_layout_id' is set
        if self.api_client.client_side_validation and ('track_layout_id' not in params or
                                                       params['track_layout_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `track_layout_id` when calling `track_layout_update_track_layout`")  # noqa: E501
        # verify the required parameter 'updated_track_layout' is set
        if self.api_client.client_side_validation and ('updated_track_layout' not in params or
                                                       params['updated_track_layout'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_track_layout` when calling `track_layout_update_track_layout`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'track_layout_id' in params:
            path_params['trackLayoutId'] = params['track_layout_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_track_layout' in params:
            body_params = params['updated_track_layout']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tracklayout/{trackLayoutId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TrackLayout',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
